<?php $TRANSLATIONS = array(
"Music" => "Música",
"songs" => "canciones",
"albums" => "álbumes",
"Add album to playlist" => "Añadir un Album a la lista.",
"Play" => "Reproducir",
"Pause" => "Pausa",
"Previous" => "Anterior",
"Next" => "Siguiente",
"Mute" => "Silenciar",
"Unmute" => "Quitar silencio",
"Rescan Collection" => "Buscar canciones nuevas",
"Artist" => "Artista",
"Album" => "Álbum",
"Title" => "Título"
);
